@@ -1,10 +1,9 @@
 # -*- coding: utf-8 -*-
 from AccessControl import getSecurityManager
-from Acquisition import aq_inner
 from plone.app.users.browser.account import AccountPanelSchemaAdapter
+from plone.app.users.browser.account import getSchema
 from plone.app.users.browser.interfaces import ILoginNameGenerator
 from plone.app.users.browser.interfaces import IUserIdGenerator
-from plone.app.users.browser.schemaeditor import getFromBaseSchema
 from plone.app.users.schema import IAddUserSchema
 from plone.app.users.schema import ICombinedRegisterSchema
 from plone.app.users.schema import IRegisterSchema
@@ -17,10 +16,8 @@ from Products.CMFCore.interfaces import ISiteRoot
 from Products.CMFCore.permissions import ManagePortal
 from Products.CMFCore.utils import getToolByName
 from Products.CMFPlone import PloneMessageFactory as _
-from Products.CMFPlone.interfaces import IPloneSiteRoot
 from Products.CMFPlone.interfaces import ISecuritySchema
 from Products.CMFPlone.interfaces import IUserGroupsSettingsSchema
-from Products.CMFPlone.utils import get_portal
 from Products.CMFPlone.utils import normalizeString
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 from Products.statusmessages.interfaces import IStatusMessage
@@ -34,7 +31,6 @@ from ZODB.POSException import ConflictError
 from zope.component import getAdapter
 from zope.component import getMultiAdapter
 from zope.component import getUtility
-from zope.component import provideAdapter
 from zope.component import queryUtility
 from zope.schema import getFieldNames
 
@@ -47,16 +43,11 @@ RENAME_AFTER_CREATION_ATTEMPTS = 100
 
 
 def getRegisterSchema():
-    portal = get_portal()
-    schema = getattr(portal, '_v_register_schema', None)
-    if schema is None:
-        portal._v_register_schema = schema = getFromBaseSchema(
-            ICombinedRegisterSchema,
-            form_name=u'On Registration'
-        )
-        # as schema is a generated supermodel,
-        # needed adapters can only be registered at run time
-        provideAdapter(AccountPanelSchemaAdapter, (IPloneSiteRoot,), schema)
+    schema = getSchema(
+        ICombinedRegisterSchema,
+        AccountPanelSchemaAdapter,
+        form_name='On Registration',
+    )
     return schema
 
 
@@ -128,6 +119,10 @@ class BaseRegistrationForm(AutoExtensibleForm, form.Form):
                 )
                 self.fields['password'].field.description = msg
 
+    def updateActions(self):
+        super(BaseRegistrationForm, self).updateActions()
+        self.actions['register'].addClass('btn-primary')
+
     def generate_user_id(self, data):
         """Generate a user id from data.
 
@@ -643,10 +638,8 @@ class AddUserForm(BaseRegistrationForm):
                 not settings.enable_user_pwd_choice
 
         # Append the manager-focused fields
-        user_group_settings = getAdapter(
-            aq_inner(self.context),
-            IUserGroupsSettingsSchema,
-        )
+        registry = getUtility(IRegistry)
+        user_group_settings = registry.forInterface(IUserGroupsSettingsSchema, prefix="plone")
         many_groups = user_group_settings.many_groups
         if not many_groups:
             allFields = defaultFields + field.Fields(IAddUserSchema)
@@ -720,4 +713,3 @@ class AddUserForm(BaseRegistrationForm):
         self.request.response.redirect(
             self.context.absolute_url() +
             '/@@usergroup-userprefs?searchstring=' + user_id)
-
