@@ -1,20 +1,18 @@
 # -*- coding: utf-8 -*-
-from plone.app.layout.navigation.interfaces import INavigationRoot
+from AccessControl.SecurityManagement import getSecurityManager
 from plone.app.users.browser.account import AccountPanelForm
 from plone.app.users.browser.account import AccountPanelSchemaAdapter
-from plone.app.users.browser.schemaeditor import getFromBaseSchema
+from plone.app.users.browser.account import getSchema
 from plone.app.users.schema import IUserDataSchema
 from plone.registry.interfaces import IRegistry
 from Products.CMFCore.utils import getToolByName
 from Products.CMFPlone import PloneMessageFactory as _
-from Products.CMFPlone.interfaces import IPloneSiteRoot
 from Products.CMFPlone.interfaces import ISecuritySchema
 from Products.CMFPlone.utils import get_portal
 from Products.CMFPlone.utils import set_own_login_name
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 from zExceptions import NotFound
 from zope.component import getUtility
-from zope.component import provideAdapter
 
 try:
     from html import escape
@@ -99,19 +97,14 @@ class UserDataPanel(AccountPanelForm):
 
 def getUserDataSchema():
     portal = get_portal()
-    schema = getattr(portal, '_v_userdata_schema', None)
-    if schema is None:
-        portal._v_userdata_schema = schema = getFromBaseSchema(
-            IUserDataSchema,
-            form_name=u'In User Profile'
-        )
-        # as schema is a generated supermodel,
-        # needed adapters can only be registered at run time
-        provideAdapter(UserDataPanelAdapter, (IPloneSiteRoot,), schema)
-        provideAdapter(UserDataPanelAdapter, (INavigationRoot,), schema)
+    form_name = u'In User Profile'
+    if getSecurityManager().checkPermission('Manage portal', portal):
+        form_name = None
+    schema = getSchema(IUserDataSchema, UserDataPanelAdapter, form_name=form_name)
     return schema
 
 
 class UserDataConfiglet(UserDataPanel):
     """Control panel version of the userdata panel"""
     template = ViewPageTemplateFile('account-configlet.pt')
+    tab = "userdata"
